# mautrix-twitter
![Languages](https://img.shields.io/github/languages/top/mautrix/twitter.svg)
[![License](https://img.shields.io/github/license/mautrix/twitter.svg)](LICENSE)
[![Release](https://img.shields.io/github/release/mautrix/twitter/all.svg)](https://github.com/mautrix/twitter/releases)
[![GitLab CI](https://mau.dev/mautrix/twitter/badges/master/pipeline.svg)](https://mau.dev/mautrix/twitter/container_registry)

A Matrix-Twitter DM puppeting bridge.

### Documentation
All setup and usage instructions are located on
[docs.mau.fi](https://docs.mau.fi/bridges/python/twitter/index.html).
Some quick links:

* [Bridge setup](https://docs.mau.fi/bridges/python/setup/index.html?bridge=twitter)
  (or [with Docker](https://docs.mau.fi/bridges/python/setup/docker.html?bridge=twitter))
* Basic usage: [Authentication](https://docs.mau.fi/bridges/python/twitter/authentication.html)

### Features & Roadmap
[ROADMAP.md](https://github.com/mautrix/twitter/blob/master/ROADMAP.md)
contains a general overview of what is supported by the bridge.

## Discussion
Matrix room: [`#twitter:maunium.net`](https://matrix.to/#/#twitter:maunium.net)
